@@ -205,7 +205,7 @@ TrackerConfig *
 tracker_config_new (void)
 {
 	return g_object_new (TRACKER_TYPE_CONFIG,
-	                     "schema-id", "org.freedesktop.Tracker.Extract",
+	                     "schema", "org.freedesktop.Tracker.Extract",
 	                     "path", "/org/freedesktop/tracker/extract/",
 	                     NULL);
 }
