@@ -51,7 +51,6 @@ typedef struct {
 
 	guint expire_timeout_id;
 	gboolean expect_finished;
-	gboolean timeout_removed;
 
 	FilesystemOperation *expect_results;
 	guint expect_n_results;
@@ -331,14 +330,6 @@ timeout_expired_cb (gpointer user_data)
 	return FALSE;
 }
 
-static void
-timeout_expired_notify_cb (gpointer user_data)
-{
-	TestCommonContext *fixture = user_data;
-
-	fixture->timeout_removed = TRUE;
-}
-
 static void
 test_common_context_expect_results (TestCommonContext   *fixture,
                                     FilesystemOperation *results,
@@ -352,20 +343,17 @@ test_common_context_expect_results (TestCommonContext   *fixture,
 	fixture->expect_finished = expect_finished;
 	fixture->expect_n_results = n_results;
 	fixture->expect_results = results;
-	fixture->timeout_removed = FALSE;
 
 	if (fixture->expect_n_results != g_list_length (fixture->ops)) {
 		if (max_timeout != 0) {
-			id = g_timeout_add_seconds_full (G_PRIORITY_DEFAULT,
-			                                 max_timeout,
-			                                 (GSourceFunc) timeout_expired_cb,
-			                                 fixture,
-			                                 timeout_expired_notify_cb);
+			id = g_timeout_add_seconds (max_timeout,
+						    (GSourceFunc) timeout_expired_cb,
+						    fixture);
 		}
 
 		g_main_loop_run (fixture->main_loop);
 
-		if (max_timeout != 0 && !fixture->timeout_removed) {
+		if (max_timeout != 0) {
 			g_source_remove (id);
 		}
 	}
